@@ -163,6 +163,43 @@ class FlareAnalysisUseCase(BaseProcessor):
             "total_frames_processed": getattr(self, '_total_frame_counter', 0)
         }
 
+    def get_config_schema(self) -> Dict[str, Any]:
+        """Get JSON schema for configuration validation."""
+        return {
+            "type": "object",
+            "properties": {
+                "confidence_threshold": {"type": "number", "minimum": 0.0, "maximum": 1.0, "default": 0.5},
+                "top_k_colors": {"type": "integer", "minimum": 1, "default": 3},
+                "frame_skip": {"type": "integer", "minimum": 1, "default": 1},
+                "target_categories": {"type": ["array", "null"], "items": {"type": "string"}, "default": ["BadFlare", "GoodFlare"]},
+                "fps": {"type": ["number", "null"], "minimum": 1.0, "default": None},
+                "bbox_format": {"type": "string", "enum": ["auto", "xmin_ymin_xmax_ymax", "x_y_width_height"], "default": "auto"},
+                "index_to_category": {"type": ["object", "null"], "default": {0: 'BadFlare', 1: 'GoodFlare'}},
+                "alert_config": {"type": ["object", "null"], "default": None},
+                "intensity_thresholds": {"type": "object", "default": {"red": 0.8, "yellow": 0.6, "orange": 0.7, "blue": 0.9, "white": 0.95}}
+            },
+            "required": ["confidence_threshold", "top_k_colors"],
+            "additionalProperties": False
+        }
+
+    def create_default_config(self, **overrides) -> FlareAnalysisConfig:
+        """Create default configuration with optional overrides."""
+        defaults = {
+            "category": self.category,
+            "usecase": self.name,
+            "confidence_threshold": 0.5,
+            "top_k_colors": 3,
+            "frame_skip": 1,
+            "target_categories": ["BadFlare", "GoodFlare"],
+            "fps": None,
+            "bbox_format": "auto",
+            "index_to_category": {0: 'BadFlare', 1: 'GoodFlare'},
+            "alert_config": None,
+            "intensity_thresholds": {"red": 0.8, "yellow": 0.6, "orange": 0.7, "blue": 0.9, "white": 0.95}
+        }
+        defaults.update(overrides)
+        return FlareAnalysisConfig(**defaults)
+
     def process(
         self,
         data: Any, 
@@ -172,115 +209,128 @@ class FlareAnalysisUseCase(BaseProcessor):
         stream_info: Optional[Dict[str, Any]] = None
     ) -> ProcessingResult:
         start_time = time.time()
-        if not isinstance(config, FlareAnalysisConfig):
-            return self.create_error_result(
-                "Invalid configuration type for flare analysis",
-                usecase=self.name,
-                category=self.category,
-                context=context
-            )
-        if context is None:
-            context = ProcessingContext()
-        if not input_bytes:
-            return self.create_error_result(
-                "input_bytes (video/image) is required for flare analysis",
-                usecase=self.name,
-                category=self.category,
-                context=context
-            )
-        if not data:
-            return self.create_error_result(
-                "Detection data is required for flare analysis",
-                usecase=self.name,
-                category=self.category,
-                context=context
-            )
-
-        input_format = match_results_structure(data)
-        context.input_format = input_format
-        context.confidence_threshold = config.confidence_threshold
-
-        processed_data = filter_by_confidence(data, config.confidence_threshold)
-        if config.index_to_category:
-            processed_data = apply_category_mapping(processed_data, config.index_to_category)
-        flare_processed_data = filter_by_categories(processed_data.copy(), config.target_categories)
-
-        if config.enable_smoothing:
-            if self.smoothing_tracker is None:
-                smoothing_config = BBoxSmoothingConfig(
-                    smoothing_algorithm=config.smoothing_algorithm,
-                    window_size=config.smoothing_window_size,
-                    cooldown_frames=config.smoothing_cooldown_frames,
-                    confidence_threshold=config.confidence_threshold,
-                    confidence_range_factor=config.smoothing_confidence_range_factor,
-                    enable_smoothing=True
-                )
-                self.smoothing_tracker = BBoxSmoothingTracker(smoothing_config)
-            flare_processed_data = bbox_smoothing(flare_processed_data, self.smoothing_tracker.config, self.smoothing_tracker)
-
         try:
-            from ..advanced_tracker import AdvancedTracker
-            from ..advanced_tracker.config import TrackerConfig
-            if self.tracker is None:
-                tracker_config = TrackerConfig()
-                self.tracker = AdvancedTracker(tracker_config)
-                self.logger.info("Initialized AdvancedTracker for flare analysis tracking")
-            flare_processed_data = self.tracker.update(flare_processed_data)
+            if not isinstance(config, FlareAnalysisConfig):
+                return self.create_error_result(
+                    "Invalid configuration type for flare analysis",
+                    usecase=self.name,
+                    category=self.category,
+                    context=context
+                )
+            if context is None:
+                context = ProcessingContext()
+            if not input_bytes:
+                return self.create_error_result(
+                    "input_bytes (video/image) is required for flare analysis",
+                    usecase=self.name,
+                    category=self.category,
+                    context=context
+                )
+            if not data:
+                return self.create_error_result(
+                    "Detection data is required for flare analysis",
+                    usecase=self.name,
+                    category=self.category,
+                    context=context
+                )
+
+            input_format = match_results_structure(data)
+            context.input_format = input_format
+            context.confidence_threshold = config.confidence_threshold
+            self.logger.info(f"Processing flare analysis with format: {input_format.value}")
+
+            processed_data = filter_by_confidence(data, config.confidence_threshold)
+            if config.index_to_category:
+                processed_data = apply_category_mapping(processed_data, config.index_to_category)
+            flare_processed_data = filter_by_categories(processed_data.copy(), config.target_categories)
+
+            if config.enable_smoothing:
+                if self.smoothing_tracker is None:
+                    smoothing_config = BBoxSmoothingConfig(
+                        smoothing_algorithm=config.smoothing_algorithm,
+                        window_size=config.smoothing_window_size,
+                        cooldown_frames=config.smoothing_cooldown_frames,
+                        confidence_threshold=config.confidence_threshold,
+                        confidence_range_factor=config.smoothing_confidence_range_factor,
+                        enable_smoothing=True
+                    )
+                    self.smoothing_tracker = BBoxSmoothingTracker(smoothing_config)
+                flare_processed_data = bbox_smoothing(flare_processed_data, self.smoothing_tracker.config, self.smoothing_tracker)
+
+            try:
+                from ..advanced_tracker import AdvancedTracker
+                from ..advanced_tracker.config import TrackerConfig
+                if self.tracker is None:
+                    tracker_config = TrackerConfig()
+                    self.tracker = AdvancedTracker(tracker_config)
+                    self.logger.info("Initialized AdvancedTracker for flare analysis tracking")
+                flare_processed_data = self.tracker.update(flare_processed_data)
+            except Exception as e:
+                self.logger.warning(f"AdvancedTracker failed: {e}")
+
+            # flare_processed_data = self._deduplicate_detections(flare_processed_data, iou_thresh=0.7)
+            self._update_flare_tracking_state(flare_processed_data)
+            self._total_frame_counter += 1
+
+            frame_number = None
+            if stream_info:
+                input_settings = stream_info.get("input_settings", {})
+                start_frame = input_settings.get("start_frame")
+                end_frame = input_settings.get("end_frame")
+                if start_frame is not None and end_frame is not None and start_frame == end_frame:
+                    frame_number = start_frame
+
+            flare_analysis = self._analyze_flares_in_media(flare_processed_data, input_bytes, config)
+            flare_summary = self._calculate_flare_summary(flare_analysis, config)
+            general_summary = self._calculate_general_summary(processed_data, config)
+            flare_summary['total_flare_counts'] = self.get_total_flare_counts()
+            insights = self._generate_insights(flare_summary, config)
+            alerts = self._check_alerts(flare_summary, config)
+            metrics = self._calculate_metrics(flare_analysis, flare_summary, config, context)
+            predictions = self._extract_predictions(flare_analysis, config)
+            summary = self._generate_summary(flare_summary, general_summary, alerts)
+
+            events_list = self._generate_events(flare_summary, alerts, config, frame_number)
+            tracking_stats_list = self._generate_tracking_stats(flare_summary, insights, summary, config, frame_number)
+            events = events_list[0] if events_list else {}
+            tracking_stats = tracking_stats_list[0] if tracking_stats_list else {}
+
+            context.mark_completed()
+            result = self.create_result(
+                data={
+                    "flare_analysis": flare_analysis,
+                    "flare_summary": flare_summary,
+                    "general_summary": general_summary,
+                    "alerts": alerts,
+                    "total_detections": len(flare_analysis),
+                    "unique_colors": len(flare_summary.get("color_distribution", {})),
+                    "events": events,
+                    "tracking_stats": tracking_stats
+                },
+                usecase=self.name,
+                category=self.category,
+                context=context
+            )
+            result.summary = summary
+            result.insights = insights
+            result.predictions = predictions
+            result.metrics = metrics
+            if config.confidence_threshold < 0.3:
+                result.add_warning(f"Low confidence threshold ({config.confidence_threshold}) may result in false positives")
+            processing_time = context.processing_time or time.time() - start_time
+            self.logger.info(f"Flare analysis completed in {processing_time:.2f}s")
+            return result
         except Exception as e:
-            self.logger.warning(f"AdvancedTracker failed: {e}")
-
-        flare_processed_data = self._deduplicate_detections(flare_processed_data, iou_thresh=0.7)
-        self._update_flare_tracking_state(flare_processed_data)
-        self._total_frame_counter += 1
-
-        frame_number = None
-        if stream_info:
-            input_settings = stream_info.get("input_settings", {})
-            start_frame = input_settings.get("start_frame")
-            end_frame = input_settings.get("end_frame")
-            if start_frame is not None and end_frame is not None and start_frame == end_frame:
-                frame_number = start_frame
-
-        flare_analysis = self._analyze_flares_in_media(flare_processed_data, input_bytes, config)
-        flare_summary = self._calculate_flare_summary(flare_analysis, config)
-        general_summary = self._calculate_general_summary(processed_data, config)
-        flare_summary['total_flare_counts'] = self.get_total_flare_counts()
-        insights = self._generate_insights(flare_summary, config)
-        alerts = self._check_alerts(flare_summary, config)
-        metrics = self._calculate_metrics(flare_analysis, flare_summary, config, context)
-        predictions = self._extract_predictions(flare_analysis, config)
-        summary = self._generate_summary(flare_summary, general_summary, alerts)
-
-        events_list = self._generate_events(flare_summary, alerts, config, frame_number)
-        tracking_stats_list = self._generate_tracking_stats(flare_summary, insights, summary, config, frame_number)
-        events = events_list[0] if events_list else {}
-        tracking_stats = tracking_stats_list[0] if tracking_stats_list else {}
-
-        context.mark_completed()
-        result = self.create_result(
-            data={
-                "flare_analysis": flare_analysis,
-                "flare_summary": flare_summary,
-                "general_summary": general_summary,
-                "alerts": alerts,
-                "total_detections": len(flare_analysis),
-                "unique_colors": len(flare_summary.get("color_distribution", {})),
-                "events": events,
-                "tracking_stats": tracking_stats
-            },
-            usecase=self.name,
-            category=self.category,
-            context=context
-        )
-        result.summary = summary
-        result.insights = insights
-        result.predictions = predictions
-        result.metrics = metrics
-        if config.confidence_threshold < 0.3:
-            result.add_warning(f"Low confidence threshold ({config.confidence_threshold}) may result in false positives")
-        processing_time = context.processing_time or time.time() - start_time
-        self.logger.info(f"Flare analysis completed in {processing_time:.2f}s")
-        return result
+            self.logger.error(f"Flare analysis failed: {str(e)}", exc_info=True)
+            if context:
+                context.mark_completed()
+            return self.create_error_result(
+                str(e),
+                type(e).__name__,
+                usecase=self.name,
+                category=self.category,
+                context=context
+            )
 
     def _is_video_bytes(self, media_bytes: bytes) -> bool:
         video_signatures = [
@@ -414,7 +464,7 @@ class FlareAnalysisUseCase(BaseProcessor):
 
     def _calculate_flare_intensity(self, main_color: str, confidence: float, config: FlareAnalysisConfig) -> float:
         threshold = config.intensity_thresholds.get(main_color, 0.5)
-        return round(confidence * (1.0 if confidence >= threshold else 0.5), 2)
+        return round(confidence * (1.0 if confidence >= self.threshold else 0.5), 2)
 
     def _calculate_flare_summary(self, flare_analysis: List[Dict], config: FlareAnalysisConfig) -> Dict[str, Any]:
         category_colors = defaultdict(lambda: defaultdict(int))
@@ -533,21 +583,21 @@ class FlareAnalysisUseCase(BaseProcessor):
                             "threshold": threshold,
                             "timestamp": datetime.now(timezone.utc).strftime('%Y-%m-%d-%H:%M:%S UTC')
                         })
-        for record in flare_summary.get("detections", []):
-            if record["category"] != "BadFlare":
-                continue
-            color = record["main_color"]
-            intensity = record["intensity"]
-            if color in config.intensity_thresholds and intensity >= config.intensity_thresholds[color]:
-                alerts.append({
-                    "type": "intensity_threshold",
-                    "severity": "critical",
-                    "message": f"{color} {record['category']} detected",
-                    "category": record["category"],
-                    "current_intensity": intensity,
-                    "threshold": config.intensity_thresholds[color],
-                    "timestamp": datetime.now(timezone.utc).strftime('%Y-%m-%d-%H:%M:%S UTC')
-                })
+                for record in flare_summary.get("detections", []):
+                    if record["category"] != "BadFlare":
+                        continue
+                    color = record["main_color"]
+                    intensity = record["intensity"]
+                    if color in config.intensity_thresholds and intensity >= config.intensity_thresholds[color]:
+                        alerts.append({
+                            "type": "intensity_threshold",
+                            "severity": "critical",
+                            "message": f"{color} {record['category']} detected with intensity {intensity}",
+                            "category": record["category"],
+                            "current_intensity": intensity,
+                            "threshold": config.intensity_thresholds[color],
+                            "timestamp": datetime.now(timezone.utc).strftime('%Y-%m-%d-%H:%M:%S UTC')
+                        })
         return alerts
 
     def _calculate_metrics(self, flare_analysis: List[Dict], flare_summary: Dict, config: FlareAnalysisConfig, context: ProcessingContext) -> Dict[str, Any]:
